<?php

namespace Entity;

use \Doctrine\Common\Collections\ArrayCollection;

/**
 * @Entity
 * @Table(name="`group`")
 */
class Group
{
    /**
     * @var     int
     * @Id
     * @GeneratedValue
     * @Column(type="integer")
     */
    protected $id = null;

    /**
     * @var     string
     * @Column(type="string")
     */
    protected $name = null;

    /**
     * @var     \Doctrine\Common\Collections\ArrayCollection
     * @ManyToMany(targetEntity="Entity\User", inversedBy="groups")
     */
    protected $members = null;

    public function __construct()
    {
        $this->setMembers(new ArrayCollection());
    }

    /**
     * @return  int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * @param   int     $id
     * @return  void
     */
    public function setId($id)
    {
        $this->id = $id;
    }

    /**
     * @return  string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * @param   string  $name
     * @return  void
     */
    public function setName($name)
    {
        $this->name = $name;
    }

    /**
     * @return  \Doctrine\Common\Collections\ArrayCollection
     */
    public function getMembers()
    {
        return $this->members;
    }

    /**
     * @param   \Doctrine\Common\Collections\ArrayCollection    $members
     * @return  void
     */
    public function setMembers(ArrayCollection $members)
    {
        $this->members = $members;
    }

    /**
     * @param   User    $member
     * @return  void
     */
    public function addMember(User $member)
    {
        $this->members->add($member);
        $member->addToGroup($this);
    }

    /**
     * @param   User    $member
     * @return  void
     */
    public function removeMember(User $member)
    {
        $this->members->removeElement($member);
        $member->removeFromGroup($this);
    }

    /**
     * @param   User    $member
     * @return  bool
     */
    public function hasMember(User $member)
    {
        return $this->members->contains($member);
    }
}
